@@ -256,14 +256,14 @@ macro_rules! match_targets{
         }
     } => {
         {
-            let __val = $targ;
+            let __val: &$crate::Target = &$targ;
             #[allow(unreachable_code)]
             loop {
                 $(if ($crate::__match_target_pattern!($($comp)-*))(&__val){
                     break $exp
                 })*
 
-                panic!("Incomplete Exhaustive Target Pattern (add a wildcard match as * => )")
+                unreachable!("Incomplete Exhaustive Target Pattern (add a wildcard match as * => )")
             }
         }
     }
@@ -284,6 +284,17 @@ mod tests {
         }
     }
 
+    #[test]
+    pub fn test_match_ref() {
+        let target = Target::parse("x86_64-pc-linux-gnu");
+        match_targets! {
+            match (&target) {
+                x86_64-pc-linux-gnu => {},
+                * => panic!("Invalid Target")
+            }
+        }
+    }
+
     #[test]
     pub fn target_match_arch_wildcard() {
         let target = Target::parse("x86_64-pc-linux-gnu");
